export default {
    "message": "Await expression cannot be a default value",
    "column": 8,
    "index": 31,
    "lineNumber": 2
}